==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnButtonOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescriptionMetadata } from "./ApplyButtonClickEventArgsDescriptionMetadata";
import { CancelButtonClickEventArgsDescriptionMetadata } from "./CancelButtonClickEventArgsDescriptionMetadata";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnButtonOptionsDescription } from "./GridColumnButtonOptionsDescription";
/**
 * @hidden
 */
export let GridColumnButtonOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnButtonOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnButtonOptionsDescriptionMetadata.a == null) {
                GridColumnButtonOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnButtonOptionsDescriptionMetadata.c(GridColumnButtonOptionsDescriptionMetadata.a);
            }
            if (a.j(GridColumnButtonOptionsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnButtonOptionsDescriptionMetadata.a);
            ApplyButtonClickEventArgsDescriptionMetadata.d(a);
            CancelButtonClickEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("ApplyButtonCaption", "String");
            a.item("CancelButtonCaption", "String");
            a.item("ApplyButtonClickRef", "EventRef::applyButtonClick");
            a.item("CancelButtonClickRef", "EventRef::cancelButtonClick");
        }
        static d(a) {
            GridColumnButtonOptionsDescriptionMetadata.b(a);
            a.aa("GridColumnButtonOptions", () => new GridColumnButtonOptionsDescription());
            a.z("GridColumnButtonOptions", GridColumnButtonOptionsDescriptionMetadata.a);
        }
    }
    GridColumnButtonOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnButtonOptionsDescriptionMetadata, 'GridColumnButtonOptionsDescriptionMetadata');
    GridColumnButtonOptionsDescriptionMetadata.a = null;
    return GridColumnButtonOptionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnButtonOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescriptionMetadata } from "./ApplyButtonClickEventArgsDescriptionMetadata";
import { CancelButtonClickEventArgsDescriptionMetadata } from "./CancelButtonClickEventArgsDescriptionMetadata";
import { GridColumnOptionsSectionBaseDescriptionMetadata } from "./GridColumnOptionsSectionBaseDescriptionMetadata";
import { GridColumnButtonOptionsDescription } from "./GridColumnButtonOptionsDescription";
/**
 * @hidden
 */
export let GridColumnButtonOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnButtonOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnButtonOptionsDescriptionMetadata.a == null) {
                GridColumnButtonOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnButtonOptionsDescriptionMetadata.c(GridColumnButtonOptionsDescriptionMetadata.a);
            }
            if (a.k(GridColumnButtonOptionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnButtonOptionsDescriptionMetadata.a);
            ApplyButtonClickEventArgsDescriptionMetadata.d(a);
            CancelButtonClickEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.c(a);
            a.item("ApplyButtonCaption", "String");
            a.item("CancelButtonCaption", "String");
            a.item("ApplyButtonClickRef", "EventRef::applyButtonClick");
            a.item("CancelButtonClickRef", "EventRef::cancelButtonClick");
        }
        static d(a) {
            GridColumnButtonOptionsDescriptionMetadata.b(a);
            a.ac("GridColumnButtonOptions", () => new GridColumnButtonOptionsDescription());
            a.ab("GridColumnButtonOptions", GridColumnButtonOptionsDescriptionMetadata.a);
        }
    }
    GridColumnButtonOptionsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnButtonOptionsDescriptionMetadata, 'GridColumnButtonOptionsDescriptionMetadata');
    GridColumnButtonOptionsDescriptionMetadata.a = null;
    return GridColumnButtonOptionsDescriptionMetadata;
})();
